@@ -278,11 +278,32 @@ Ext.define('MP.desktop.App', {
                         _('Are you sure you want to logout?'),
                         function(bid) {
                             if(bid==='yes') {
+                                var maskel = me.getDesktop().getEl();
+
+                                maskel.mask('<span id="pbar"></span>');
+
+                                var pbar = Ext.create('Ext.ProgressBar', {
+                                    text: _("Please Wait..."),
+                                    width: 180,
+                                    renderTo: 'pbar',
+                                    value: 1
+                                });
+
                                 Ext.Ajax.request({
                                     url: '/auth/logout',
-                                    method: 'GET'
+                                    method: 'GET',
+                                    success: function() {
+                                        pbar.reset(true);
+                                        maskel.unmask();
+                                        me.fireEvent('logout', me);
+                                    },
+                                    failure: function(response) {
+                                        pbar.reset(true);
+                                        maskel.unmask();
+                                        me.fireEvent('logout', me);
+                                        console.error('Something went wrong: ', response);
+                                    }
                                 });
-                                me.fireEvent('logout', me);
                             }
                         });
     }
