@@ -43,7 +43,6 @@ Ext.define('MP.window.Login', {
     closable: false,
     resizable: false,
     draggable: false,
-    autoHeight: true,
     layout: 'fit',
     border: false,
     modal: true,
@@ -64,7 +63,7 @@ Ext.define('MP.window.Login', {
                 items: me.getFormFields()
             }]
         });
-        me.callParent(arguments);
+        me.callParent();
     },
 
     buttons: [{
