@@ -109,17 +109,17 @@ def catalog_view(request):
     try:
         app_catalog = locale.translations._domains[domain]
     except KeyError:
-        logger.warning('Could not find "%s" translation catalog for "%s",'
-                       ' maybe it has not been compiled? Falling back to'
-                       ' the "native" language.', domain, name)
+        logger.debug('Could not find "%s" translation catalog for "%s",'
+                     ' maybe it has not been compiled? Falling back to'
+                     ' the "native" language.', domain, name)
         app_catalog = None
 
     try:
         desktop_catalog = locale.translations._domains['mp-desktop']
     except KeyError:
-        logger.warning('Could not find "%s" translation catalog for "%s",'
-                       ' maybe it has not been compiled? Falling back to'
-                       ' "native" language.', "mp-desktop", name)
+        logger.debug('Could not find "%s" translation catalog for "%s",'
+                     ' maybe it has not been compiled? Falling back to'
+                     ' "native" language.', "mp-desktop", name)
         desktop_catalog = None
 
     if app_catalog is desktop_catalog is None:
